/*******************************************************
Purpose: Create analytical sample from CRELES pre-1945 (WAVE 1 & 2) and Retirement Cohort (RC) data 
Author: Jing Li, UC Berkeley
Date: 05/18/2013
*****************************************************/

clear all
set more off, permanently
cap log close

/* change to local directory where data files are stored */
cd "/Users/jingli/Dropbox/Costa Rica Project/Analysis/CRELES_RC/Fert_Models"

global data "/Users/jingli/Dropbox/Costa Rica Project/Analysis/CRELES_RC/CRELES_RC_w1"
global latex "/Users/jingli/Dropbox/Costa Rica Project/Analysis/CRELES_RC/Latex/"


/// STEP 1: DATA PREPARATION

 *** keep necessary variables from each file****
 // Main File
	use "$data/MainForm_RC_w1_v1.dta", clear

	** Rename and keep key vars
	keep idsujeto hhid psu numseg key1 amp2 a3 amp4 am6-am8 a7a-a7c a8 a9 a10 a14 a11a a11b a22a-a25 age urban eduyear educlevel factor_princ

	rename key1 prov
	
	rename amp2 sex
	gen female = (sex==2)
	
	rename a3 marital_stus	
	rename amp4 informant
	
	* number of children	
	rename am6 child_num	
	rename am7 child_alive	
	rename am7b child_spouse	
	rename am7ba child_spouse_alive
	rename am7c tot_child_alive
	rename am8 tot_child_inhouse
	
	* Marriage
	rename a7a end_relation_yr
	rename a7b yrs_ago_end_Relation
	rename a7c end_relation_age
	
	rename a8 liv_tgthr_yr
	rename a9 age_diff
	rename a10 older
	rename a14 oth_partner
	
	* education
	/*rename id3 age
	rename a2a edu_lvl
	rename a2b edu_yrs*/
	renam a11a edu_lvl_spouse
	rename a11b edu_yrs_spouse
	
	* locality
	rename a22a  birth_ct_indicator
	rename a22b1 birth_prov
	rename a22b  birth_cn
	rename a23   yrs_birth_cn
	rename a24a  long_ct_indicator
	rename a24b1 long_prov
	rename a24b  long_ct
	rename a25   yrs_long_ct
	
	save main, replace

	
 // Family member file
 
 	* Children file
 	use "$data/HouseholdMembers_RC_w1_v1.dta", clear	
 	keep idsujeto hhid psu numseg key1 ab2-ab4 abn1 abn2 ab6 	
 	* keep only children obs
 	rename ab2 relation
 	keep if relation == 3 | relation==4 
 	
 	rename ab3 sex
 	gen female = (sex==2)
 	
 	rename ab4 age
 	rename abn1 educlevel
 	rename abn2 eduyear
 	rename ab6 live_together
 	
 	save child_resident, replace
 
 // Spouse file
 	use "$data/Spouse_RC_w1_v1.dta", clear	
	keep /*idsujeto*/ hhid /*psu numseg*/ age 
	
	save spouse, replace 
 
 // Nonresident children file
 	use "$data/NonResidentChildren_RC_w1_v1.dta", clear	
 	keep idsujeto hhid psu numseg key1 ac2-ac4 acn1 acn2
 	
 	rename ac2 sex
 	gen female = (sex==2)
 	
 	rename ac3 whose_child
 	rename ac4 age
 	
 	rename acn1 educlevel
 	rename acn2 eduyear
 
 	save child_nonresident, replace
 
 // Deceased children file
 	use "$data/DeceasedChildren_RC_w1_v1.dta", clear
 	keep idsujeto hhid psu numseg key1 ad2 ad3 ad5
 	
 	rename ad2 sex
 	gen female = (sex==2) 
 	
 	rename ad3 whose_child
 	rename ad5 age_died
 	
 	save child_deceased, replace
 	
 // Append all children files
 	use child_resident, clear
 	append using child_nonresident child_deceased, gen (filenum)
 	save child_all, replace 
 	
 	gsort +hhid +idsujeto -age
 	by hhid idsujeto: gen childid = _n
 	
 	rename key1 prov
 	
 	save child_all, replace


 ***** SAMPLE SELECTION *************** 	
 // Extract qualified parents  	
 	use main, clear
 	
 	rename hijosfall child_num_deceased
 	
 	* keep those parents with at least one child and no child belonging only to the spouse
 	keep if child_num>0 & (child_spouse == . | child_spouse==0)
 	
 	* Keep those parents who has married before but never had another spouse
 	keep if oth_par == 2
 	
 	save main_sample1, replace
 
  // Merge with spouse and children file
  
  	* Modify variables, prepare for merging
  	use main_sample1, clear
  	
  	rename age index_age
  	rename sex index_sex
  	rename female index_female
 	
 	* Merge with spouse file
 	merge 1:1 hhid using spouse, keep(match master) nogen
 	rename age spouse_age
 	 	  	
  	* Generate mom age
  	gen mom_age = .
  	replace mom_age = index_age if index_female==1
	replace mom_age = spouse_age if index_female == 0
  	
  	* Recode spouse education using recode var code
  	rename edu_yrs_spouse edu_grade_spouse
  	gen eduyear_spouse = edu_grade_spouse
  	recode eduyear_spouse .=3 9=3
  	replace eduyear_spouse = 0 if edu_lvl_spouse == 0
  	replace eduyear_spouse = eduyear_spouse + 6 if edu_lvl_spouse==2 | edu_lvl_spouse==3
  	replace eduyear_spouse = eduyear_spouse+11  if edu_lvl_spouse==4 | edu_lvl_spouse==5
  	tab eduyear_spouse edu_grade_spouse
  	la var eduyear_spouse "Education years of spouse approved"
  	
  	gen educlevel_spouse = 0 if eduyear_spouse==0
  	replace educlevel_spouse=1 if eduyear_spouse<=6 & eduyear_spouse>=1
  	replace educlevel_spouse=2 if eduyear_spouse>6 & eduyear_spouse<=11
  	replace educlevel_spouse=3 if eduyear_spouse>11
  	la var educlevel_spouse "Level of education-spouse"
  	la val educlevel_spouse educlevel
  	
  	* generate education variables for mom and dad
  	gen mom_eduyear = eduyear 
  	replace mom_eduyear = eduyear_spouse if index_female ==0
  	
  	gen dad_eduyear = eduyear 
  	replace dad_eduyear = eduyear_spouse if index_female ==1
   	
  	save main_sample1, replace

	* Merge
	use main_sample1, clear
	drop edu*
  	merge 1:m hhid idsujeto psu numseg prov using child_all, keep(match master)
  	save family_sample1, replace

  	
  // Further restrict sample in merged file
  	sort hhid idsujeto childid
  	
  	* Exclude families with step children
  	gen exclude_child = (relation == 4) | (whose_child== 3)|(whose_child== 4)|(whose_child== 9)
  	tab exclude_child
	egen exclude_family = sum(exclude_child), by(hhid idsujeto)
	tab exclude_family
	drop if exclude_family>0
	
	* Exclude families with children who died at or over age 6
	replace exclude_child = 1 if age_died >=6 & age_died~=.
	drop exclude_family
 	egen exclude_family = sum(exclude_child), by(hhid idsujeto)
 	tab exclude_family
 	drop if exclude_family>0
 	
 	* Exclude children who died below age 6, but keep the families
 	replace exclude_child = 1 if age_died<6
 	drop if exclude_child ==1
 	
 	* Recreate childid
 	rename childid childid_old
 	gsort +hhid +idsujeto -age
 	by hhid idsujeto: gen childid = _n
 	
 	* Examine consistency in number of children
 	gen _counter = 1
 	egen child_alive_new = sum(_counter), by (hhid idsujeto)
 	gen inconsis = (child_alive~=child_alive_new)
 	tab inconsis
 	/*
 	use family_sample1, clear
 	
 	keep if inconsis==1
 	gsort +hhid +idsujeto -age
 	save inconsistent, replace*/
 	
 	* Exclude families with inconsistent number of children
 	/*use family_sample1, clear*/
 	drop if inconsis==1
 	
 	* Exclude families with parents born or are residents in a foreign country
 	drop if a22c~=. | a24c~=.
 	drop a22c a24c
 	save family_sample1, replace
 
 	use family_sample1, clear
 	
 	* recode child education vars
 	rename eduyear edugrade
 	gen eduyear = edugrade
   	recode eduyear .=3 9=3
  	replace eduyear = 0 if educlevel == 0
  	replace eduyear = educlevel + 6 if educlevel==2 | educlevel==3
  	replace eduyear = eduyear+11    if educlevel==4 | educlevel==5
  	tab eduyear edugrade
  	la var eduyear "Education years of child"
  	
  	capture drop educlevel
  	gen educlevel = 0 if eduyear==0
  	replace educlevel=1 if eduyear<=6 & eduyear>=1
  	replace educlevel=2 if eduyear>6 & eduyear<=11
  	replace educlevel=3 if eduyear>11
  	la var educlevel "Level of education of child"
  	la val educlevel educlevel
  	
  	* Rename and relabel vars
  	drop age_died child_spouse* child_num_deceased
  	rename birth_cn birth_ct
  	rename idsujeto index_id
  	
  	la var mom_age "Mother's age"
  	la var mom_eduyear "Mother's years of education"
  	la var sex "Child sex"
  	la var female "Child female"
  	la var age "Child age"
  	
  	save family_sample1, replace  
  	
  	* Exclude families with children whose age is missing
  	use family_sample1, clear
  	replace exclude_child=1 if age>=999
  	capture drop exclude_family
  	egen exclude_family = sum(exclude_child), by (hhid index_id)
  	drop if exclude_family>0
  	
  	/*
  	* Exclude families with no more than 2 children
  	use family_sample1, clear
  	drop if child_alive <=2 */	
  	
  	save family_sample1, replace  
  	
  	/************************************************
  	***** Merge on confidential file w/ canton info**
  	*************************************************/
  	
  	use family_sample1, clear
  	merge m:1 psu numseg using "$data/psu-canton.dta", nogen
  	save family_sample1_ct, replace
  	
  	* Create canton lived longest var
  	gen canton_long = canton
    replace canton_long = long_ct if long_ct_indicator == 2	
  	
  	* Create mom age at first birth var
    egen age_oldest = max(age), by(hhid index_id)
    gen mom_age_birth = mom_age - age_oldest
    drop if mom_age_birth < 14
    
    * Create any sister var
    egen num_girls = sum(female), by(hhid index_id)
    gen anygirl = (num_girls>0)
    gen anysis = anygirl
    replace anysis = 0 if female==1 & num_girls==1 
    
    * Create DV and IV
    gen attend_second = (educlevel>1)
    gen sibling_num = child_alive - 1
    
    save family_sample1_ct, replace
    
  	
  	
  	
/// Step 3: Create instruments
    use family_sample1_ct, clear
    drop if child_alive < 2
    save family_sample1_2child, replace
    
    * Create instruments
    gsort +hhid +index_id -age
    by hhid index_id: gen firstgirl = (female[1]==1)
    by hhid index_id: gen secondgirl = (female[2]==1)
    
    gen firsttwogirls = (firstgirl==1 & secondgirl ==1)
    gen firsttwoboys  = (firstgirl==0 & secondgirl ==0)
    gen firsttwosamesex = (firstgirl == secondgirl)
    
    la var firsttwogirls "First two born girls"
    la var firsttwoboys "First two born boys"
    
	save family_sample1_2child, replace



cd "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/Fert_Models"

global data1 "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_w1"
global data2 "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_w2"
global latex "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/Latex/"
global RC    "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/Fert_Models/RC_Data"

/// Step 1: Wave 2 File Extraction

	// MAIN AND HH MEMBER FILE
	
	use "$data2/ElderlyPeople_w2.dta", clear
	keep CASEID id2c id4
	rename id2c main_birth_yr
	rename id4  main_sex
	save all_elderly, replace
	
	use "$data2/HouseholdMembers_w2.dta", clear
	keep if ab2 ==1 | ab2 ==2
	gen birth_yr = 2007-ab4
	gen sex = ab3
	keep CASEID ab2 birth_yr sex
	
	merge m:1 CASEID using all_elderly, nogen
	replace ab2 = 1 if ab2 ==. 
	replace birth_yr = main_birth_yr if ab2==1
	replace sex = main_sex if ab2==1
	drop main_*
	duplicates drop CASEID ab2, force
	
	* reshape data from long to wide
	reshape wide sex birth_yr, i(CASEID) j(ab2)
	gen mom_birth_yr = birth_yr1 if sex1 == 2
	replace mom_birth_yr = birth_yr2 if sex2 == 2
	
	gen dad_birth_yr = birth_yr1 if sex1 == 1
	replace dad_birth_yr = birth_yr2 if sex2 == 1
	save all_parent, replace
	
	
	// HH CHILD FILE
	* Get hh children with education info
	use "$data2/HouseholdMembers_w2.dta", clear
	keep if ab2 == 3 | ab2 == 4
	
	sort CASEID 
	by CASEID: gen child_id = _n
	egen num_hh_child = max(child_id), by(CASEID)
	
	rename ab2 relation
	rename ab3 child_sex 
	rename ab4 child_age 
	rename abn1 child_edulvl  
	rename abn2 child_eduyr 
	drop if child_edulvl == 9 | child_eduyr == 9 | child_edulvl ==. | child_sex == 9 | child_age == 99

	
	keep CASEID relation child_sex child_age child_edulvl child_eduyr num_hh_child
	
	* Check if all children in hh are found
	gen count = 1
	egen num_found = sum(count), by (CASEID)
	gen all_found = (num_hh_child== num_found)
	tab all_found
	keep if all_found==1
	
	gen in_hh = 1
	save all_hh_child, replace
	
	
	// NON-RESIDENT CHILD FILE
	* Get non-resident children with education info
	use "$data2/NonResidentChildren_w2.dta", clear
	sort CASEID 
	by CASEID: gen child_id = _n
	egen num_nonres_child = max(child_id), by(CASEID)
	
	rename ac3 relation
	rename ac2 child_sex 
	rename ac4 child_age 
	rename acn1 child_edulvl  
	rename acn2 child_eduyr 

	drop if relation == 9
	drop if child_edulvl == 9 | child_eduyr == 9 | child_edulvl ==. | child_sex == 9 | child_age == 99
	
	keep CASEID relation child_sex child_age child_edulvl child_eduyr num_nonres_child
	
	* Check if all nonresident children of hh are found
	gen count = 1
	egen num_found = sum(count), by (CASEID)
	gen all_found = (num_nonres_child== num_found)
	tab all_found
	keep if all_found==1
	
	gen in_hh = 0
	save all_nonres_child, replace
	
	// COMBINE HH AND NONRES CHILD
	use all_nonres_child, clear
	drop num* all* 
	append using all_hh_child, keep(CASEID relation child_sex child_age child_edulvl child_eduyr in_hh)
	
	capture drop count
	gen count = 1
	egen num_child = sum(count), by(CASEID)

	gsort +CASEID -child_age
	save all_child, replace
	
	/*
	* apply age restriction
	keep if mom_birth_yr >= 1930 & mom_birth_yr <= 1945*/
	
	
	// MERGE CHILD FILE W/ PARENT FILE
	use all_child, clear
	merge m:1 CASEID using all_parent, keep(match master) nogen
	
	* drop same sex parent
	drop if sex1==sex2
	
	* drop kids that are not own children
	drop if relation == 2 | relation == 4	
	
	* reexamine if all child in hh are found
	egen num_child2 = sum(count), by(CASEID)
	gen all_found = (num_child== num_child2)
	tab all_found
	keep if all_found==1
	
	save all_family, replace
	
	// MERGE ON OTHER PARENT INFORMATION ON SPOUSE
	use "$data2/ElderlyPeople_w2.dta", clear
	keep CASEID am7 a3 an1 a9 a10 a11a a11b a13an 
	
	rename am7 num_living_child
	rename a3 marital_status
	rename an1 same_partner
	rename a9 age_diff
	rename a10 who_older
	rename a11a spouse_edulvl
	rename a11b spouse_eduyr
	rename a13an widow_lst2
	
	merge 1:m CASEID using all_family, keep(match) nogen
	
	save all_family, replace
	
	// DROP IF CHILD NUM DOES NOT MATCH ** But since there too many inconsistencies, keep them for now
	
	use all_family, clear
	sort CASEID
	
	gen consis_num_child = (num_living_child== num_child)
	tab consis_num_child
	save all_family, replace
	
	keep if consis_num_child==1
	save all_family_consis, replace
	
	* investigate inconsistent child number
	use all_family
	keep if consis_num_child==0
	gen diff = num_living_child - num_child
	tab diff
	save inconsis, replace

***********************************	
//// test child num inconsistency *
***********************************
	
	use "$data2/HouseholdMembers_w2.dta", clear
	keep if ab2 ==3 | ab2 ==4
	sort CASEID
	by CASEID: gen child_id1 = _n
	keep CASEID child_id1
	save hh_child_100pct, replace	
	
	use "$data2/NonResidentChildren_w2.dta", clear
	sort CASEID
	by CASEID: gen child_id2 = _n
	keep CASEID child_id2
	save nonres_child_100pct, replace
	
	append using hh_child_100pct
	sort CASEID
	by CASEID: gen child_id = _n
	egen num_child = max(child_id), by(CASEID)
	save child_100pct, replace
	
	use "$data2/ElderlyPeople_w2.dta", clear
	keep CASEID am7
	rename am7 num_living_child
	
	merge 1:m CASEID using child_100pct, keep(match)
	gen consis = (num_child == num_living_child)
	tab consis
	

/// Step 2: Wave 1 File Extraction
	
// MAIN AND HH MEMBER FILE
	
	use "$data1/ElderlyPeople.dta", clear
	keep CASEID key1 id2c id4 am6 am7 am9 am9a a2a a2b a3 a9 a10 a11a a11b a14 a22a a22b a24a a24b
	
	rename key1 province
	rename id2c main_birth_yr
	rename id4 	main_sex
	
	rename am6 num_liveborn_child
	
	rename am9 age_firstborn
	rename am9a yr_firstborn
	rename a2a main_edulvl
	rename a2b main_eduyr
	
	rename a3 maritalstatus
	rename a9 age_diff
	rename a10 who_older
	rename a11a spouse_edulvl
	rename a11b spouse_eduyr
	rename a14 other_partner
	
	rename a22a birth_plc
	rename a22b birth_canton 
	
	rename a24a longest_plc
	rename a24b longest_canton 
	
	save elderly_w1, replace
	
	
/// Step 3: Merge w1 and w2 to get parents' education
	use all_family, clear
	rename num_living_child num_living_child_w2
	rename marital_status marital_status_w2
	rename num_child num_child_found
	
	drop spouse_* num_child2 all_found age_diff who_older
	
	merge m:1 CASEID using elderly_w1, keep(match) nogen
	
	save merge12_family, replace
	
	
	
	use merge12_family, clear
	
	** DROP IF MALE INTERVIEWEE HAD OTHER PARTNER 
	drop if main_sex == 1 & (other_partner == 1 | other_partner == 9)
	
	** DROP IF INTERVIEWEE AGE OR SEX IS INCONSISTENT
	gen inconsis_sex = (main_sex ~= sex1)
	tab inconsis_sex
	
	gen inconsis_age = (main_birth_yr ~= birth_yr1)
	tab inconsis_age
	drop if inconsis_age==1
	
	** DROP IF NEVER MARRIED
	drop if maritalstatus == 8
		
	** create mom's birth year
	gen mom_birthyr_final = mom_birth_yr
	replace mom_birthyr_final = main_birth_yr if age_diff == 0 & mom_birth_yr == .
	replace mom_birthyr_final = main_birth_yr - age_diff if who_older==1 & mom_birth_yr == .
	replace mom_birthyr_final = main_birth_yr + age_diff if who_older==2 & mom_birth_yr == .
	
	** DROP IF DON'T KNOW WHO'S OLDER
	drop if who_older == 9
	
	** RESTRICT MOM BIRTH YEAR TO 1930-1945
	codebook mom_birthyr_final
	keep if mom_birthyr_final >= 1930 & mom_birthyr_final <= 1945
	
	* examine child number inconsistency (for now do not drop inconsistent child number)
	gen inconsis_child_num = (am7~= num_child_found)
	tab inconsis_child_num
	
	* DROP CHILDREN W/ MISSING AGE
	tab child_age
	drop if child_age == 999
	
	* MAKE SURE ALL CHILDREN ARE KEPT IN ONE FAMILY
	egen num_child_found2 = sum(count), by(CASEID)
	gen all_found = (num_child_found2 == num_child_found)
	tab all_found
	drop if all_found==0
	
	save fam_final, replace


/// STEP 4: create key variables

	// 1. generate MOM EDUCATION
	use fam_final, clear
	
	gen mom_edulvl = main_edulvl if main_sex == 2
	replace mom_edulvl = spouse_edulvl if main_sex == 1
	
	gen mom_eduyr = main_eduyr if main_sex == 2
	replace mom_eduyr = spouse_eduyr if main_sex == 1

	** The following code is taken from the CRELES documentation
	***Years of education: eduyear**. 
	gen mom_eduyear= mom_eduyr 
	recode mom_eduyear .=0 9=3 
	replace mom_eduyear= mom_eduyear+6 if mom_edulvl==2 | mom_edulvl==3 
	replace mom_eduyear= mom_eduyear+11 if mom_edulvl==4 | mom_edulvl==5 
	/*replace mom_eduyear = eduyr_cen if eduyear==. */
	lab var mom_eduyear "Mother's education years approved" 
	***Level of education: educlevel 
	gen mom_educlevel=0 if mom_eduyear==0 
	replace mom_educlevel=1 if mom_eduyear<=6 & mom_eduyear>=1 
	replace mom_educlevel=2 if mom_eduyear>6 & mom_eduyear<=11 
	replace mom_educlevel=3 if mom_eduyear>11 
	la var mom_educlevel "Mother's level of education approved"
	
	
	// 2. generate children's education
	gen child_eduyear= child_eduyr 
	recode child_eduyear .=0 9=3 
	replace child_eduyear= child_eduyear+6 if child_edulvl==2 | child_edulvl==3 
	replace child_eduyear= child_eduyear+11 if child_edulvl==4 | child_edulvl==5 
	/*replace mom_eduyear = eduyr_cen if eduyear==. */
	lab var child_eduyear "Child's education years approved" 
	***Level of education: educlevel 
	gen child_educlevel=0 if child_eduyear==0 
	replace child_educlevel=1 if child_eduyear<=6 & child_eduyear>=1 
	replace child_educlevel=2 if child_eduyear>6 & child_eduyear<=11 
	replace child_educlevel=3 if child_eduyear>11 
	la var child_educlevel "Child's level of education approved"
	
	gen attend_second = (child_educlevel>1)
	la var attend_second "Attended secondary school"
	
	//3. Other vars: Number of siblings, IVs, anysis, mom's age at first birth etc.
	gsort CASEID -child_age
	by CASEID: gen child_id = _n
	
	gen age = child_age
	la var age "Child age"
	
	gen sibling_num = num_child_found-1
	la var sibling_num "Number of siblings"
	
	gen female = (child_sex==2)
	
	by CASEID: gen firstgirl = (child_sex[1]==2)
	by CASEID: gen secondgirl = (child_sex[2]==2)
	gen firsttwogirls = (firstgirl==1 & secondgirl==1)
	gen firsttwoboys  = (firstgirl==0 & secondgirl==0)
	la var firsttwogirls "First two born girls"
    la var firsttwoboys "First two born boys"
	
	egen num_girls = sum(female), by(CASEID)
	gen anysis = 0
	replace anysis = 1 if female==0 & num_girls>=1
	replace anysis = 1 if female==1 & num_girls>=2
	la var anysis "Any sister"
	
	gen mom_age_birth = 2007-child_age-mom_birthyr_final
	la var mom_age_birth "Mother's age at first birth"
	
	save fam_final_allvars, replace
	
	// 4. Merge on w/ canton info
	use "$data1/track-oldCRELES.dta", clear
		gen CASEID = idsujeto
		keep CASEID canton
		merge 1:m CASEID using fam_final_allvars, keep(match) nogen
		save fam_final_allvars, replace
	
		use fam_final_allvars, clear
		gen canton_long = canton
		replace canton_long=longest_canton if longest_canton~=. & longest_plc~=1
		codebook canton_long
	save fam_final_allvars, replace
	
	// 5. Create final analytical sample to be merged on with RC cohort
	use fam_final_allvars, clear
	keep if num_child_found>=2
	sort CASEID child_id
	keep CASEID child_id attend_second sibling_num anysis mom_eduyear mom_age_birth mom_birthyr_final canton_long age female firsttwogirls firsttwoboys	
	save sample_pre1945, replace
	
	
	/************************************************************************
	// 6. Create alternative samples since the original one yields 
		insignificant results in IV model
	*************************************************************************/
	
	use fam_final_allvars, clear
	
	drop if num_liveborn_child~=num_child_found
	gen agesq = age^2
	ivregress 2sls attend_second anysis mom_eduyear mom_age_birth age agesq i.canton_long ///
			(sibling_num = firsttwogirls firsttwoboys) if (female ==1), cluster(canton_long) first

	
	/*
	reg attend_second sibling_num anysis mom_eduyear mom_age_birth i.canton_long i.age if (female ==1), ///
			cluster(canton_long)
	ivregress 2sls attend_second anysis mom_eduyear mom_age_birth i.age i.canton_long ///
			(sibling_num = firsttwogirls firsttwoboys) if (female ==1), cluster(canton_long) first

	reg attend_second sibling_num anysis mom_eduyear mom_age_birth i.canton_long i.age if (female ==0), ///
			cluster(canton_long)
	ivregress 2sls attend_second anysis mom_eduyear mom_age_birth i.age i.canton_long ///
			(sibling_num = firsttwogirls firsttwoboys) if (female ==0), cluster(canton_long) first
	
	collapse (mean) attend_second , by (female sibling_num)

	twoway connected attend_second sibling_num if female == 0, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected attend_second sibling_num if female ==1, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Secondary Education Attendance by Number of Siblings", size(4)) ///
			ylabel(0(.1)1) ytitle("Fraction Attending Secondary School") xlabel(0(2)14) xtitle("Number of Siblings") ///
			legend(label(1 "Male") label(2 "Female")) */



/// Step 5: Append with RC sample to run models
	use "$RC/family_sample1_2child.dta", clear
	keep index_id childid attend_second sibling_num anysis mom_eduyear mom_age mom_age_birth canton_long age female firsttwogirls firsttwoboys
	gen CASEID=index_id
	rename childid child_id 
	gen mom_birthyr_final = 2010-mom_age
	save sample_rc, replace
	
	append using sample_pre1945
	
	drop if age<14
	gen num_child = sibling_num+1
	la var num_child 		 "Number of currently living children"
	la var mom_birthyr_final "Birth year of mother"
	la var mom_age_birth 	 "Mother's age at first birth"
	save sample_combined, replace
	
	duplicates drop CASEID, force
	save sample_mom_combined, replace
	
	use sample_mom_combined, clear
  	hist num_child, freq title("Frequency of Families by Number of Children Alive")
  	graph export familysize.png, replace
	
	use sample_combined, replace
	collapse (mean) attend_second /*[pw=factor_princ]*/, by (female sibling_num)
  	
  	twoway connected attend_second sibling_num if female == 0, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected attend_second sibling_num if female ==1, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Secondary Education Attendance by Number of Siblings (Age>=14)", size(4)) ///
			ylabel(0(.1)1) ytitle("Fraction Attending Secondary School") xlabel(0(2)14) xtitle("Number of Siblings") ///
			legend(label(1 "Male") label(2 "Female")) 
	graph export attend_sec.png, replace

	use sample_combined, replace
	reg attend_second sibling_num anysis mom_eduyear mom_age_birth i.canton_long i.age if (female ==1), ///
			cluster(canton_long)
		
	reg attend_second firsttwogirls firsttwoboys anysis mom_eduyear mom_age_birth i.canton_long i.age if (female ==1), ///
			cluster(canton_long)
			
	reg sibling_num firsttwogirls firsttwoboys anysis mom_eduyear mom_age_birth /*i.canton_long i.age*/ if (female ==1), ///
			cluster(canton_long)
			
	ivregress 2sls attend_second anysis mom_eduyear mom_age_birth i.age i.canton_long ///
			(sibling_num = firsttwogirls firsttwoboys) if (female ==1), cluster(canton_long) first

	reg attend_second sibling_num anysis mom_eduyear mom_age_birth i.canton_long i.age if (female ==0), ///
			cluster(canton_long)
	ivregress 2sls attend_second anysis mom_eduyear mom_age_birth i.age i.canton_long ///
			(sibling_num = firsttwogirls firsttwoboys) if (female ==0), cluster(canton_long) first

	gen anysis_f = anysis*female
	gen sibling_num_f = sibling_num*female
	
	ivregress 2sls attend_second anysis anysis_f mom_eduyear mom_age_birth i.age i.canton_long ///
			(sibling_num sibling_num_f = firsttwogirls firsttwoboys), cluster(canton_long) first

	
	use sample_mom_combined, clear
	reg num_child mom_eduyear mom_age_birth firsttwoboys firsttwogirls i.canton_long, cluster(canton_long)
	
	
	/********************************************
	RC Sample 2
	*********************************************/
	
	use "$RC/family_sample2_2child.dta", clear
	keep index_id childid attend_second sibling_num anysis mom_eduyear mom_age mom_age_birth canton_long age female firsttwogirls firsttwoboys mom_birthyr
	gen CASEID=index_id
	rename childid child_id 
	gen mom_birthyr_final = mom_birthyr
	save sample2_rc, replace
	
	append using sample_pre1945
	
	/*drop if age<14*/
	gen num_child = sibling_num+1
	la var num_child 		 "Number of currently living children"
	la var mom_birthyr_final "Birth year of mother"
	la var mom_age_birth 	 "Mother's age at first birth"
	drop if mom_age_birth<14
	save sample2_combined, replace
	
	duplicates drop CASEID, force
	save sample2_mom_combined, replace
	
