/*********************************************************
Purpose: Create analytical sample from IPUMS 2000 Costa Rica data 
Author: Jing Li, UC Berkeley
**********************************************************/

clear all
set more off, permanently
cap log close

/* change to local directory where data files are stored */
cd "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation/Fertility_Schooling_Investigation"

global latex "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation/Fertility_Schooling_Investigation/Latex/"
global dir="/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation"
global econ= "/Users/jingli/Google Drive/Costa Rica Project/Analysis/Econ Indicator"


/// 1. Descriptive stats of child sample

	
	use "$dir/census1984_all.dta", clear
		keep if cr84a_age>=13 & cr84a_age<=20
	
	save child_1984, replace

/// 2. child mother match
	use child_1984, clear
		merge 1:1 year serial pernum wtper using "$dir/family_relations.dta", keepusing(momloc) keep(match master) nogen
	/*save child_1984, replace
	
	use child_1984, clear*/	
		tab momloc
		drop if momloc==0 | momloc>9
	save child_1984_mom, replace

	use "$dir/census1984_all.dta", clear 
		keep if cr84a_sex==2 & cr84a_age>=30 & cr84a_age<=65 & cr84a_chborn >= 1 & cr84a_chborn < 98
		keep year serial cr84a_dwnum cr84a_hhnum pernum cr84a_age cr84a_relate cr84a_chborn cr84a_edattain cr84a_grade cr84a_grade2 
		
		rename cr84a_age mom_age
		rename cr84a_relate momloc
		
		rename cr84a_chborn mom_chborn
		rename cr84a_grade2 mom_yrschool
		
		rename cr84a_edattain mom_edattain
		rename cr84a_grade mom_lstyred
		
		duplicates report cr84a_dwnum cr84a_hhnum momloc
		duplicates tag cr84a_dwnum cr84a_hhnum momloc, gen(dupe)
		keep if dupe==0
			
	save mom1984, replace
	
	
	use child_1984_mom, clear
		merge m:1 year serial cr84a_dwnum cr84a_hhnum momloc using mom1984, keepusing(mom_age mom_chborn mom_yrschool mom_edattain mom_lstyred) ///
			keep(master match) nogen
			
		gen match = (mom_age ~=.)
		keep if match == 1
		
		** Keep only relevant age groups
		drop if cr84a_age<13 | cr84a_age>20
	save child_1984_mommatch, replace
	
	label var mom_age "Mother's age"
	label var mom_chborn "Mother's children ever born"
	
	* Mother's education
	label var mom_yrschool "Mother's year of schooling"
	label var mom_edattain "Mother's education attainment"
	label var mom_lstyred 	"Mother's last year of completed schooling"
	
	* Child's education
	label var cr84a_school "School attendance"
	label var cr84a_grade  "Last year of completed schooling"
	
	save child_1984_mommatch, replace

	
	
/// Descriptive statistics
	use child_1984_mommatch, clear
		gen any_sec = (cr84a_grade > 16)
		tab any_sec
		
	save child_1984_mommatch, replace
	
	* Clean children ever born variable
	use child_1984_mommatch, clear
		/*drop if mom_chborn == 0 | mom_chborn > 25*/
		gen num_sib = mom_chborn-1
		replace num_sib = 12 if mom_chborn > 12
	
		gen att_sch = (cr84a_school == 1)
	tab num_sib
	tab att_sch
	
	save child_1984_mommatch, replace
	
	* Graph of any secondary school - All
	use child_1984_mommatch, clear
	collapse (mean) any_sec, by (num_sib cr84a_sex)
	twoway connected any_sec num_sib if cr84a_sex == 1, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected any_sec num_sib if cr84a_sex ==2, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Any Secondary School by Sibling Number, Cohort 1964-1971", size(4)) ///
			ylabel(0(.2)1) ytitle("Any Secondary School") xlabel(0(1)12) xtitle("Sibling Number") ///
			legend(label(1 "Male") label(2 "Female")) 
	graph export anysec_size_all.png, replace
	
	
	* Graph of any secondary school - by period
	use child_1984_mommatch, clear
	
	gen period = 1 /*if birth_yr >= 1964 & birth_yr <= 1967*/
	replace period = 2 if birth_yr > 1967
	
	save child_1984_mommatch, replace
	
	
	use child_1984_mommatch, clear
	collapse (mean) any_sec, by (num_sib cr84a_sex period)
	twoway connected any_sec num_sib if cr84a_sex == 1 & period == 1, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected any_sec num_sib if cr84a_sex ==2 & period == 1, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Any Secondary School by Sibling Number, Cohort 1964-1967", size(4)) ///
			ylabel(0(.2)1) ytitle("Any Secondary School") xlabel(0(1)12) xtitle("Sibling Number") ///
			legend(label(1 "Male") label(2 "Female")) 
	graph export anysec_size_1.png, replace
	
	twoway connected any_sec num_sib if cr84a_sex == 1 & period == 2, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected any_sec num_sib if cr84a_sex ==2 & period == 2, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Any Secondary School by Sibling Number, Cohort 1968-1971", size(4)) ///
			ylabel(0(.2)1) ytitle("Any Secondary School") xlabel(0(1)12) xtitle("Sibling Number") ///
			legend(label(1 "Male") label(2 "Female")) 
	graph export anysec_size_2.png, replace
	
	
	* Graph of attending school
	use child_1984_mommatch, clear
	collapse (mean) att_sch, by (num_sib cr84a_sex)
	twoway connected att_sch num_sib if cr84a_sex == 1, msymbol(D) mfcolor(white) mlcolor(black) msize(small) ///
		|| connected att_sch num_sib if cr84a_sex ==2, msymbol(S) mcolor(gs10) msize(small) ///
		||, title("Sibling Number on Attending School (1984 Census), Cohort 1964-1971", size(4)) ///
			/*ylabel(0(.05).5)*/ ytitle("Attending School") xlabel(0(1)12) xtitle("Family Size") ///
			legend(label(1 "Male") label(2 "Female")) 
	graph export attend_size_all, replace


/// Sex Composition of younger siblings

	use "$dir/census1984_all.dta", clear 
		keep if cr84a_age<=12
		merge 1:1 year serial pernum wtper using "$dir/family_relations.dta", keepusing(momloc) keep(match master) nogen
		drop if momloc==0 | momloc>9
	save sibs_all, replace
	
	* Produce sex composition variables by household & momloc	
	use sibs_all, clear
		sort cr84a_dwnum cr84a_hhnum momloc
		gen female = (cr84a_sex == 2)
		
		
		/************/
		gen counter = 1
	save sibs_all, replace
	
		collapse (sum) female, by (cr84a_dwnum cr84a_hhnum momloc)
		rename female num_girls
	save sex_comp, replace
	
	use child_1984_mommatch, replace
		merge m:1 cr84a_dwnum cr84a_hhnum momloc using sex_comp, keepusing(num_girls) keep(match master) /*nogen*/	
		rename num_girls num_sis 
		gen any_sis = (num_sis >0)
	save child_1984_sibmatch, replace
	
	
	* Descriptives of education and number of YOUNGER sisters
	use child_1984_sibmatch, clear
	keep if num_sis~=.
	drop if num_sis>num_sib
	/*
	keep if mom_chborn == 4
	drop if num_sis>3*/
	collapse (mean) any_sec (sum) counter, by (cr84a_sex num_sib num_sis)
	sort cr84a_sex num_sib num_sis
	
/// Models
	
	* Merge data with LFP controls
	
	use child_1984_sibmatch, clear
		gen yr_sec = birth_yr + 13
		gen yr_lag1 = birth_yr + 14
		gen yr_lag2 = birth_yr + 15
		gen yr_presec = birth_yr + 12
	save child_1984_sibmatch, replace
	
	use "$econ/canton_yr.dta", clear 
		gen cr84a_resprev2 = canton
	save canton_yr, replace
	
	foreach var in yr_sec yr_lag1 yr_lag2 yr_presec {
		
			use canton_yr, clear			
				gen `var' = year
				gen lfp_`var' = lfp
			save canton_yr_2, replace
			
			use child_1984_sibmatch, clear
			merge m:1 cr84a_resprev2 `var' using canton_yr_2, keepusing(lfp_`var') keep(match master) nogen 
			save child_1984_sibmatch, replace	
		
		}
	
	** additional variables
	
	use child_1984_sibmatch, clear
		gen birth_age = mom_age - cr84a_age
	
	/*
	gen shock = (period ==2)
	gen sib_shock = num_sib * shock*/
	
	gen shock = (birth_yr >= 1968)
	gen sib_shock = num_sib * shock
	save child_1984_final, replace	
	
	
	use child_1984_final, clear
	
		gen sib_1 = (num_sib==1)
		gen sib_2 = (num_sib==2)
		gen sib_3 = (num_sib==3)
		gen sib_4 = (num_sib==4)
		gen sib_5 = (num_sib==5)
		gen sib_6 = (num_sib==6)
		gen sib_7 = (num_sib>=7)
		
		forvalues num=1(1)6 {
			label var sib_`num' "`num' sibling(s)"
		}
		
		label var sib_7 "At least 7 siblings"
		label var num_sib "# siblings"
		label var sib_shock "# siblings * after shock" 
	
	save child_1984_final, replace
	
	use child_1984_final, clear
	keep if female == 0 
	/*qui any_sec num_sib mom_yrschool birth_age  i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)*/
	qui reg any_sec num_sib mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store m1
	
	qui reg any_sec num_sib sib_shock mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store m2
	
	qui reg any_sec sib_1-sib_7 mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store m3
	
	

	use child_1984_final, clear
	keep if female == 1
	
	qui reg any_sec num_sib mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store f1
	
	qui reg any_sec num_sib sib_shock mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store f2
	
	qui reg any_sec sib_1-sib_7 mom_yrschool birth_age lfp_yr_sec i.cr84a_resprev2 i.birth_yr, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store f3
	
	esttab f1 f2 f3 m1 m2 m3 using "${latex}sib_anysec.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(num_sib sib_1 sib_2 sib_3 sib_4 sib_5 sib_6 ///
	sib_7 sib_shock mom_yrschool birth_age lfp_yr_sec) ///
	title("OLS Estimators of the Effect of Sibling Number on Probability of Any Secondary School") ///
	align(ccc) width(\hsize) addnotes("Note: Standard errors adjusted for clustering at canton level.")
	
	
	
	
	
	
	
	
	keep if cr84a_bplcant == 1 & cr84a_resprev == 1
	
	
	
	** canton by year FE
	use child_1984_final, clear
		gen canton_yr = cr84a_resprev2 * birth_yr
	save child_1984_final, replace
	
	keep if female == 1 & cr84a_bplcant == 1 & cr84a_resprev == 1
	qui reg any_sec num_sib mom_yrschool birth_age i.canton_yr, cluster(canton_yr)
	est table, keep (num_sib mom_yrschool birth_age) se t p style(oneline)

	/*qui*/ reg any_sec i.num_sib mom_yrschool birth_age i.canton_yr, cluster(canton_yr)
	/*est table, keep (num_sib mom_yrschool birth_age) se t p style(oneline)*/



/// TRY IV: pull out siblings age 0-20 and keep those for whom all siblings are found in the same household

	 use "$dir/census1984_all.dta", clear 
		keep if cr84a_age<=20
		merge 1:1 year serial pernum wtper using "$dir/family_relations.dta", keepusing(momloc) keep(match master) nogen
		drop if momloc==0 | momloc>9
	save sibs_all_iv, replace
	
	* Collapse at household-momloc level to obtain total number of siblings per mom
	use sibs_all_iv, clear
		gen counter=1
		gen female = (cr84a_sex == 2)
		sort cr84a_dwnum cr84a_hhnum momloc
		collapse (sum) counter female, by (cr84a_dwnum cr84a_hhnum momloc)
		rename counter num_kids
		rename female num_girls
	save hh_sib_num, replace
	
	
	* Examine relationship between sex composition and family size
	use hh_sib_num, clear
		gen counter = 1
		gen pct_girls = num_girls/num_kids
		/*
		gen sex_ratio = (num_kids-num_girls)/num_girls*/
		collapse (mean) pct_girls (sum) counter, by(num_kids)
	
	twoway connected pct_girls num_kids
	
	* Obtain eligible kids (age 13-20, all siblings found in the hh)
	use child_1984_mommatch, replace
		/*drop counter*/
		merge m:1 cr84a_dwnum cr84a_hhnum momloc using hh_sib_num, keepusing(num_kids num_girls) keep(match master) /*nogen*/	
		keep if mom_chborn == num_kids
	save child_1984_iv, replace
	
	* Obtain eligible hh list of eligible kids
	keep cr84a_dwnum cr84a_hhnum momloc
	duplicates drop
	save hh_1984_iv, replace	
	
	
	* Obtain all siblings in eligible hh (of eligible kids)
	use sibs_all_iv, clear
		merge m:1 cr84a_dwnum cr84a_hhnum momloc using hh_1984_iv
		keep if _merge == 3
	save sibs_iv, replace
	
	* Obtain the sex of the first two children
	use sibs_iv, clear
	gsort cr84a_dwnum cr84a_hhnum momloc -cr84a_age
	
	gen birth_order = 1
	replace birth_order = birth_order[_n-1]+1 if cr84a_dwnum==cr84a_dwnum[_n-1] & ///
												cr84a_hhnum==cr84a_hhnum[_n-1] & momloc==momloc[_n-1]
	
	save sibs_iv, replace
	
	cd "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/IV"

global IPUMSINV "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation/Fertility_Schooling_Investigation"
global RC "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_RC_w1"
global CRELES "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES FINAL"
global IPUMS "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Final"

global latex "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/LaTex"

/*------------------------------------------------------
	GET RID OF TWINS, RE-CREATE SAMPLE
--------------------------------------------------------*/
	
	/* CHILDREN AGE 0-20, NO TWINS WITH THE SAME MOM*/	
	use "$IPUMSINV/sibs_iv", clear
	
	/*keep if serial==6586001*/
	keep if cr84a_age<=20
	
	gen any_sec = (cr84a_grade > 16)
	gen age = cr84a_age
	gen female = (cr84a_sex==2)

	
	duplicates tag cr84a_dwnum cr84a_hhnum momloc cr84a_age, gen(twins)
	egen sumtwins = total(twins), by (cr84a_dwnum cr84a_hhnum momloc)
	drop if sumtwins>0
	
	by cr84a_dwnum cr84a_hhnum momloc: egen num_kids = count(cr84a_age)
	gen sibling_num = num_kids-1
	gen mom_chborn = num_kids
	
	keep if num_kids>=2
	
	by cr84a_dwnum cr84a_hhnum momloc: egen num_female = sum(female)
	gen num_male = num_kids-num_female

	gen anysis = ((female==0 & num_female>0)|(female==1 & num_female>1))
	gen anybro = ((female==0 & num_male>1)|(female==1 & num_male>0))

	
	
		
	
	save child_1984_all, replace
	
	use child_1984_all, clear
		merge m:1 year serial cr84a_dwnum cr84a_hhnum momloc mom_chborn using "$IPUMSINV/mom1984", keepusing(mom_age mom_chborn mom_yrschool mom_edattain mom_lstyred) ///
			keep(match) nogen
	gen birth_yr = 1984-age
	label var mom_age "Mother's age"
	label var mom_chborn "Mother's children ever born"
	
	* Mother's education
	label var mom_yrschool "Mother's year of schooling"
	label var mom_edattain "Mother's education attainment"
	label var mom_lstyred 	"Mother's last year of completed schooling"
	
	* Children
	label var cr84a_school "School attendance"
	label var cr84a_grade  "Last year of completed schooling"
		
	save child_1984_mommatch, replace
			
	/*keep if serial==6586001*/
	
	
	use child_1984_mommatch, replace
	keep if birth_order<=3
	
	sort cr84a_dwnum cr84a_hhnum momloc
	by cr84a_dwnum cr84a_hhnum momloc: egen oldest_age = max(age)
	gen mom_age_birth = mom_age - oldest_age
	
	keep cr84a_dwnum cr84a_hhnum momloc female birth_order mom_age_birth
	reshape wide female, i(cr84a_dwnum cr84a_hhnum momloc mom_age_birth) j(birth_order)
	save sex_3_iv, replace
	
	use child_1984_mommatch, clear
	keep if age>=13
	capture drop female1 
	capture drop female2 
	capture drop _merge
	merge m:1 cr84a_dwnum cr84a_hhnum momloc using sex_3_iv, keepusing(female* mom_age_birth) keep(match) nogen
	
	
	gen bb = (female1 == 0 & female2 == 0)
	gen gg = (female1 == 1 & female2 == 1)
	gen bg = (female1 == 0 & female2 == 1)

	save child_1984_final_notwins, replace
