
/*******************************************************
Purpose: Create analytical sample from IPUMS 2000 Costa Rica data
Author: Jing Li, UC Berkeley
Date: 02/21/2014
*****************************************************/

clear all
set more off, permanently
cap log close

/* change to local directory where data files are stored */
cd "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/yr 2000 sample"

global OLD "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/IV"

global IPUMSINV "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation/Fertility_Schooling_Investigation"
global RC "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_RC_w1"
global CRELES "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES FINAL"
global IPUMS "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Final"

global dir "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation"

global latex "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/LaTex/"


// Configure 2000 data into IV data

use "$dir/census2000.dta", clear 
		keep if cr00a_age<=20
		merge 1:1 year serial pernum wtper using "$dir/family_relations.dta", keepusing(momloc) keep(match master) nogen
		drop if momloc==0 | momloc>9
	save sibs_all_iv, replace
	
	* Collapse at household-momloc level to obtain total number of siblings per mom
	use sibs_all_iv, clear
		gen counter=1
		gen female = (cr00a_sex == 2)
		sort cr00a_dwnum cr00a_hhnum momloc
		collapse (sum) counter female, by (cr00a_dwnum cr00a_hhnum momloc)
		rename counter num_kids
		rename female num_girls
	save hh_sib_num, replace
	
	
	* Examine relationship between sex composition and family size
	use hh_sib_num, clear
		gen counter = 1
		gen pct_girls = num_girls/num_kids
		/*
		gen sex_ratio = (num_kids-num_girls)/num_girls*/
		collapse (mean) pct_girls (sum) counter, by(num_kids)
	
	twoway connected pct_girls num_kids
	
	* Extract mom info
	use "$dir/census2000.dta", clear 
		keep if cr00a_sex==2 & cr00a_age>=30 & cr00a_age<=65 & cr00a_chborn >= 1 & cr00a_chborn < 98
		keep year serial cr00a_dwnum cr00a_hhnum pernum cr00a_age cr00a_relate cr00a_chborn cr00a_edattain cr00a_grade cr00a_yrschool 
		
		rename cr00a_age mom_age
		rename cr00a_relate momloc
		
		rename cr00a_chborn mom_chborn
		rename cr00a_yrschool mom_yrschool
		
		rename cr00a_edattain mom_edattain
		rename cr00a_grade mom_lstyred
		
		duplicates report cr00a_dwnum cr00a_hhnum momloc
		duplicates tag cr00a_dwnum cr00a_hhnum momloc, gen(dupe)
		keep if dupe==0
			
	save mom2000, replace

	* Merge children and mothers, keeping only children whose siblings are all found
	use sibs_all_iv, clear
		merge m:1 year serial cr00a_dwnum cr00a_hhnum momloc using mom2000, keepusing(mom_age mom_chborn mom_yrschool mom_edattain mom_lstyred) ///
			keep(master match) nogen
			
		gen match = (mom_age ~=.)
		keep if match == 1
		
		merge m:1 cr00a_dwnum cr00a_hhnum momloc using hh_sib_num, keepusing(num_kids num_girls) keep(match master)	
		keep if mom_chborn == num_kids
	save sibs_iv, replace
	
	
	
	use sibs_iv, clear
		gen any_sec = (cr00a_grade > 26)
		gen age = cr00a_age
		gen female = (cr00a_sex==2)

		duplicates tag cr00a_dwnum cr00a_hhnum momloc cr00a_age, gen(twins)
		egen sumtwins = total(twins), by (cr00a_dwnum cr00a_hhnum momloc)
		drop if sumtwins>2
	
		/*by cr00a_dwnum cr00a_hhnum momloc: egen num_kids = count(cr00a_age)*/
		gen sibling_num = num_kids-1	
		/*keep if num_kids>=2*/
	
		gen num_boys = num_kids-num_girls

		gen anysis = ((female==0 & num_girls>0)|(female==1 & num_girls>1))
		gen anybro = ((female==0 & num_boys>1)|(female==1 & num_boys>0))	
		gen birth_yr = 2000-age
		
	label var mom_age "Mother's age"
	label var mom_chborn "Mother's children ever born"
	
	* Mother's education
	label var mom_yrschool "Mother's year of schooling"
	label var mom_edattain "Mother's education attainment"
	label var mom_lstyred 	"Mother's last year of completed schooling"
	
	* Children
	label var cr00a_school "School attendance"
	label var cr00a_grade  "Last year of completed schooling"
		
	save child_2000_all, replace
			
	/*keep if serial==6586001*/
	
	
	use child_2000_all, clear
	
	gsort cr00a_dwnum cr00a_hhnum momloc -cr00a_age
	
	by cr00a_dwnum cr00a_hhnum momloc: gen birth_order=_n
	
	/*
	gen birth_order = 1
	replace birth_order = birth_order[_n-1]+1 if cr84a_dwnum==cr84a_dwnum[_n-1] & ///
												cr84a_hhnum==cr84a_hhnum[_n-1] & momloc==momloc[_n-1]*/
			
	by cr00a_dwnum cr00a_hhnum momloc: egen oldest_age = max(age)
	gen mom_age_birth = mom_age - oldest_age
	
	save child_2000_all, replace
	
	* Drop kids born outside of CR
		drop if cr00a_arryr~=0
		
		

	save child_2000_all, replace
	
	
	use child_2000_all, clear
		keep if age>=13
		keep if num_kids >=2
	save child_2000_iv, replace
	
	
		
	// Add wealth vars
	use child_2000_iv, clear
		merge 1:1 cntry year sample serial cr00a_dwnum cr00a_hhnum cr00a_pernum using "$dir/census2000_hh.dta", keep(match master) nogen
		
		/* Running water*/
		gen w_water=0
		replace w_water=1 if cr00a_watsup==1
	
		/* Toilet*/
		gen w_toilet=0
		replace w_toilet = 1 if cr00a_toilet==1 
			
		/* tv */
		gen w_tv=0
		replace w_tv = 1 if cr00a_tv==1
	
		/* fridge*/
		gen w_refrig=0
		replace w_refrig = 1 if cr00a_refrig==1 
	
		/*phone */
		gen w_phone=0
		replace w_phone = 1 if cr00a_phone==1
	
		/*washer*/
		gen w_washer=0
		replace w_washer = 1 if cr00a_washer==1
	
		/*car*/
		gen w_car=0
		replace w_car = 1 if cr00a_car==1
	
		gen wealth = w_water+w_toilet+w_tv+w_refrig+w_phone+w_washer+w_car
save child_2000_iv_allvars, replace
		
		
	gsort +cr00a_dwnum +cr00a_hhnum +momloc -cr00a_age
	by cr00a_dwnum cr00a_hhnum momloc: gen parity = _n
	
	gen twinparity_ind = 0
	replace twinparity_ind = parity if twins==1
	
	by cr00a_dwnum cr00a_hhnum momloc: egen twinparity=sum(twinparity_ind)
	replace twinparity=(twinparity-1)/2 if sumtwins>0
	replace parity=parity-1 if sumtwins>0 & parity>twinparity
	
	by cr00a_dwnum cr00a_hhnum momloc: egen num_parity = max(parity)
save child_2000_final_twins, replace
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
