/**************************************************************************
PURPOSE: Produce final tables and graphs in Li, Dow & Rosero-Bixby (2014):The Declining Effect of Sibling Size on Childrens Education in Costa
Rica 
This .do file takes the outputs from IPUMS1984_Sample.do, IPUMS2000_Sample.do, CRELES_Sample.do as inputs
********************************************************************/

clear all
set more off, permanently
cap log close

cd "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION"

global IPUMSINV "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Investigation/Fertility_Schooling_Investigation"
global RC "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_RC_w1"
global NRC "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES/CRELES_w1"


global CRELES "/Users/jingli/Google Drive/Costa Rica Project/Analysis/CRELES FINAL"
global IPUMS "/Users/jingli/Google Drive/Costa Rica Project/Analysis/IPUMS Final"

global YR84 "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/IV"
global YR00 "/Users/jingli/Google Drive/Costa Rica Project/Analysis/REVISION/yr 2000 sample"

global latex "/Users/jingli/Google Drive/Costa Rica Project/Manuscript/May 2014/LaTex/"


//// TABLE 1

/*----------------------------------
*** SAMPLE 1: 1984 CENSUS NO TWINS
------------------------------------*/

use "$YR84/child_1984_final_notwins.dta", replace

	gen morethan2 = (sibling_num>1)
	gen morethan3 = (sibling_num>2)

	capture drop _merge
	merge 1:1 year serial cr84a_dwnum cr84a_hhnum cr84a_pernum using more_vars_84_00, keepusing(cr84a_watsrc cr84a_tvcol cr84a_refrig) keep(match master)
	
	/*-------------
	Appliances:
     Auto
     Clothes washer
     Refrigerator
     TV of any kind
	Utilities / dwelling charact
     Phone (line or cell)
     Water supply
     Toilet
     ---------------*/

	/* Running water*/
	gen w_water=0
	replace w_water=1 if cr84a_watsrc==1 | cr84a_watsrc==2 | cr84a_watsrc==3 | cr84a_watsrc==4
	
	/* Toilet*/
	gen w_toilet=0
	replace w_toilet = 1 if cr84a_toilet==1 | cr84a_toilet==2
	
	/* tv */
	gen w_tv=0
	replace w_tv = 1 if cr84a_tvbw==2 | cr84a_tvcol==2
	
	/* fridge*/
	gen w_refrig=0
	replace w_refrig = 1 if cr84a_refrig==2 
	
	/*phone */
	gen w_phone=0
	replace w_phone = 1 if cr84a_phone==2
	
	/*washer*/
	gen w_washer=0
	replace w_washer = 1 if cr84a_washer==2
	
	/*car*/
	gen w_veh=0
	replace w_veh = 1 if cr84a_vehicle==2
	
	gen wealth = w_water+w_toilet+w_tv+w_refrig+w_phone+w_washer+w_veh
	
	la var any_sec "Any secondary school"
	la var sibling_num "Number of siblings"
	la var morethan2 "More than two children"
	la var morethan3 "More than three children"
	la var gg  "First two girls"
	la var bb  "First two boys"
	la var anysis "Any sisters"
	la var birth_yr "Year of birth"
	la var mom_yrschool "Mother's years of schooling"
	la var mom_age_birth "Mother's age at first birth"
	la var wealth "Wealth index"
	

save child_1984_final_notwins, replace

use child_1984_final_notwins, clear

keep if birth_order<=2 & cr84a_age>=14



local varlist any_sec sibling_num female morethan2 morethan3 gg bb anysis birth_yr age mom_yrschool mom_age_birth wealth
eststo clear
estpost tabstat `varlist', listwise s(mean sd) columns(statistics)
esttab using "${latex}table1.tex", label replace main(mean) aux(sd) nostar nodepvar unstack nomtitle nonumber /*noobs*/ ///
addnotes("Mean of each variable with standard deviation in parentheses.") ///
/*label title("Summary of spinoff founders and other partners (at least 4 board seats)\label{spinfounder}") replace nonotes*/







/*----------------------------------
*** SAMPLE 2: 2000 CENSUS NO TWINS
------------------------------------*/

use "$YR00/child_2000_iv_allvars.dta", replace

gen morethan2 = (sibling_num>1)
gen morethan3 = (sibling_num>2)

keep if sibling_num>=1

	la var any_sec "Any secondary school"
	la var sibling_num "Number of siblings"
	la var morethan2 "More than two children"
	la var morethan3 "More than three children"
	la var gg  "First two girls"
	la var bb  "First two boys"
	la var anysis "Any sisters"
	la var birth_yr "Year of birth"
	la var mom_yrschool "Mother's years of schooling"
	la var mom_age_birth "Mother's age at first birth"
	la var wealth "Wealth index"


save child_2000_iv_notwins, replace

use child_2000_iv_notwins, clear
keep if birth_order<=2 & cr00a_age>=14

local varlist any_sec sibling_num female morethan2 morethan3 gg bb anysis birth_yr age mom_yrschool mom_age_birth wealth
eststo clear
estpost tabstat `varlist', listwise s(mean sd) columns(statistics)
esttab using "${latex}table1b.tex", label replace main(mean) aux(sd) nostar nodepvar unstack nomtitle nonumber /*noobs*/ ///
addnotes("Mean of each variable with standard deviation in parentheses.") ///


/*label twins, drop triplets
	duplicates tag cr00a_dwnum cr00a_hhnum momloc cr00a_age, gen(twins)
	egen sumtwins = total(twins), by (cr00a_dwnum cr00a_hhnum momloc)
	drop if sumtwins>2
	
	gsort +cr00a_dwnum +cr00a_hhnum +momloc -cr00a_age
	by cr00a_dwnum cr00a_hhnum momloc: gen parity = _n
	
	gen twinparity_ind = 0
	replace twinparity_ind = parity if twins==1
	
	by cr00a_dwnum cr00a_hhnum momloc: egen twinparity=sum(twinparity_ind)
	replace twinparity=(twinparity-1)/2 if sumtwins>0
	replace parity=parity-1 if sumtwins>0 & parity>twinparity
	

	/*keep if sumtwins>0
	
	by cr84a_dwnum cr84a_hhnum momloc: egen num_parity = max(parity)
save child_2000_iv_twins, replace

use child_2000_iv_twins, replace
	drop if twinparity>0
save child_2000_iv_notwins, replace*/


/*----------------------------------
*** SAMPLE 3: CRELES
------------------------------------*/

use "$CRELES/sample2_combined.dta", replace

	duplicates tag CASEID age, gen(twins)
	egen sumtwins = total(twins), by (CASEID)
	drop if sumtwins>2
	
	gsort +CASEID -age
	by CASEID: gen parity = _n
	
	gen twinparity_ind = 0
	replace twinparity_ind = parity if twins==1
	
	by CASEID: egen twinparity=sum(twinparity_ind)
	replace twinparity=(twinparity-1)/2 if sumtwins>0
	replace parity=parity-1 if sumtwins>0 & parity>twinparity
	
	by CASEID: egen num_parity = max(parity)
	
	gen idsujeto = CASEID
	capture drop _merge
	
	merge m:1 idsujeto using "$RC/MainForm_RC_w1_v1.dta", keepusing(j*) keep(match master) 
	gen found1 = (_merge==3)
	capture drop _merge
	
	merge m:1 CASEID using "$NRC/ElderlyPeople.dta", keepusing(j*) keep(match master)
	gen found2 = (_merge==3) 
	capture drop _merge

/*	
save creles_nowealth, replace*/
	
	**Wealth scale of amenities**.
	capture drop amen*
	gen amen4=0 /*running water */
	replace amen4=1 if j26==1
	replace amen4=. if j26==. |j26==9

	gen amen5=0 /*toilet */
	replace amen5=1 if j27==1
	replace amen5=. if j27==. |j27==9

	gen amen6=0 /*rrefrigerator*/
	replace amen6=1 if j20==1
	replace amen6=. if j20==. |j20==9

	gen amen7=0  /*TV any kind*/
	replace amen7=1 if j28>=1 & j28<=3
	replace amen7=. if j28==. |j28==9

	gen amen8=0 /*phone -- line or cell*/
	replace amen8=1 if j21==1 | j22==1
	replace amen8=. if j21==. & j22==.
	replace amen8=. if j21==9 & j22==9

	gen amen9=0 /* clothes washer */
	replace amen9=1 if j23==1
	replace amen9=. if j23==. |j23==9

	gen amen10=0 /* car */
	replace amen10=1 if j29>=1 & j29<=3
	replace amen10=. if j29==. |j29==9


	**The wealth scale**
	gen amenities=amen4+amen5+amen6+amen7+amen8+amen9+amen10
	
	la var attend_second "Any secondary school"
	la var sibling_num "Number of siblings"
	la var morethan2 "More than two children"
	la var morethan3 "More than three children"
	la var firsttwogirl  "First two girls"
	la var firsttwoboys  "First two boys"
	la var anysis "Any sisters"
	la var child_birthyr "Year of birth"
	la var mom_eduyear "Mother's years of schooling"
	la var mom_age_birth "Mother's age at first birth"
	la var wealth "Wealth index"

	
	gen morethan2 = (sibling_num>1)
	gen morethan3 = (sibling_num>2)

save creles_iv_twins, replace

use creles_iv_twins, clear
	drop if sumtwins>0
save creles_iv_notwins, replace

use creles_iv_notwins, clear
keep if parity<=2 /*& age>=14*/
/*gen idsujeto = CASEID*/
	capture drop _merge
	
	merge m:1 idsujeto using "$RC/MainForm_RC_w1_v1.dta", keepusing(j*) keep(match master) 
	gen found1 = (_merge==3)
	capture drop _merge
	
	merge m:1 CASEID using "$NRC/ElderlyPeople.dta", keepusing(j*) keep(match master)
	gen found2 = (_merge==3) 
	capture drop _merge






local varlist attend_second sibling_num female morethan2 morethan3 firsttwogirls firsttwoboys anysis child_birthyr age mom_eduyear mom_age_birth /*wealth*/
eststo clear
estpost tabstat `varlist', listwise s(mean sd) columns(statistics)
esttab using "${latex}table1c.tex", label replace main(mean) aux(sd) nostar nodepvar unstack nomtitle nonumber /*noobs*/ ///
addnotes("Mean of each variable with standard deviation in parentheses.") ///


/// TABLE 2: PROGRESSION RESULTS
	
	use child_1984_final_notwins_2, clear

	duplicates drop serial /*sibling_num mom_eduyear mom_age_birth bb gg*/, force
	
	gen third_kid = (sibling_num>=2)
	gen fourth_kid = .
	replace fourth_kid = (sibling_num>=3) if third_kid==1
	gen fifth_kid = .
	replace fifth_kid = (sibling_num>=4) if fourth_kid==1

	save hhlvl_1984, replace
	
	use hhlvl_1984, clear
	/*qui*/ reg third_kid female1 female2 gg mom_yrschool mom_age_birth wealth i.cr84a_resprev2, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store p1
	
	
	/*qui*/ reg fourth_kid female1 female2 gg mom_yrschool mom_age_birth wealth i.cr84a_resprev2, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store p2
	
	
	/*qui*/ reg fifth_kid female1 female2 gg mom_yrschool mom_age_birth wealth i.cr84a_resprev2, cluster(cr84a_resprev2)
	estadd ysumm
	estimates store p3
	
	esttab p1 p2 p3 using "${latex}progression_0602.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(female1 female2 gg) ///
	mtitles("Third Child" "Fourth Child" "Fifth Child") ///
	title("The Effect of Sex Composition of the First Two Children on Progression of Births") ///
	align(ccc) width(\hsize) nonotes addnotes("Note: Standard errors adjusted for clustering at canton level. Each observation is at the household level. Other controls include mother's education, mother's age at first birth and family wealth.")
 	


/// TABLE 3: FIRST STAGE
/*
	use creles_iv_notwins, clear
	capture drop birth2
	gen birth2 = (parity==2)
	gen f_anysis = female* anysis
	gen gg=firsttwogirls 
	gen bb=firsttwoboys
	gen mom_yrschool = mom_eduyear
	gen canton_fe = canton_long
	gen birth_yr = child_birthyr
	save creles_iv_notwins, replace*/
	
	use creles_iv_notwins, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	
	keep if parity<=2

	local controls anysis birth2 mom_yrschool mom_age_birth 
	/*
	reg sibling_num bb anysis birth2 mom_yrschool mom_age_birth i.birth_yr i.canton_fe, cluster(canton_fe)
	test bb

	ivregress 2sls attend_second anysis birth2 mom_yrschool mom_age_birth i.birth_yr i.canton_fe (sibling_num=bb), cluster(canton_fe)
	ivregress 2sls attend_second anysis birth2 mom_yrschool mom_age_birth i.birth_yr i.canton_fe (sibling_num=gg) if female==1, cluster(canton_fe)

	
	qui reg sibling_num `controls' female f_anysis i.canton_fe, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f1a
	
	qui reg sibling_num gg `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f1b*/
	
	qui reg sibling_num gg `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f1c
	
/*
	use child_1984_final_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr84a_resprev2
	save child_1984_final_notwins_2, replace*/
	
	use child_1984_final_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe



	keep if birth_order<=2 & cr84a_age>=14
	
	local controls gg bb anysis birth2 mom_yrschool mom_age_birth wealth

		
	qui reg sibling_num `controls' female f_anysis i.birth_yr i.canton_fe, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f2a
	
	qui reg sibling_num `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f2b
	
	qui reg sibling_num `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f2c	
	
	
	/*
	use child_2000_iv_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr00a_res5cant
	save child_2000_iv_notwins_2, replace*/

	use child_2000_iv_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	keep if birth_order<=2 & cr00a_age>=14

	local controls gg bb anysis birth2 mom_yrschool mom_age_birth wealth
	
	qui reg sibling_num `controls' female f_anysis i.birth_yr i.canton_fe, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f3a
	
	qui reg sibling_num `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f3b
	
	qui reg sibling_num `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	test bb gg
	estadd ysumm
	estimates store f3c	
	
		
	esttab f1a f1b f1c f2a f2b f2c f3a f3b f3c using "${latex}RegTable2.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(gg bb) ///
	/*mtitles("OLS" "1st" "RF" "IV" "OLS" "1st Stage" "RF"  "IV")*/ ///
	title("2SLS and I Estimates of The Effect of Sibling Number on Prob. of Attending Secondary School") ///
	align(ccccccccc) width(\hsize) /*nonotes*/ addnotes("Note: Standard errors adjusted for clustering at canton level. Each observation is at the child level.")
 	

/// OLS tables

use creles_iv_notwins, clear

	gen any_sec = attend_second
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	
	keep if parity<=2

	local controls anysis birth2 mom_yrschool mom_age_birth 
	
	qui reg any_sec sibling_num `controls' female f_anysis i.canton_fe, cluster(canton_fe)

	estadd ysumm
	estimates store f1a
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	estadd ysumm
	estimates store f1b
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	estadd ysumm
	estimates store f1c
	
/*
	use child_1984_final_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr84a_resprev2
	save child_1984_final_notwins_2, replace*/
	
	use child_1984_final_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe



	keep if birth_order<=2 & cr84a_age>=14
	
	local controls anysis birth2 mom_yrschool mom_age_birth wealth

		
	qui reg any_sec sibling_num `controls' female f_anysis i.birth_yr i.canton_fe, cluster(canton_fe)
	estadd ysumm
	estimates store f2a
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	estadd ysumm
	estimates store f2b
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	estadd ysumm
	estimates store f2c	
	
	
	/*
	use child_2000_iv_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr00a_res5cant
	save child_2000_iv_notwins_2, replace*/

	use child_2000_iv_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	keep if birth_order<=2 & cr00a_age>=14

	local controls anysis birth2 mom_yrschool mom_age_birth wealth
	
	qui reg any_sec sibling_num `controls' female f_anysis i.birth_yr i.canton_fe, cluster(canton_fe)
	estadd ysumm
	estimates store f3a
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==0, cluster(canton_fe)
	estadd ysumm
	estimates store f3b
	
	qui reg any_sec sibling_num `controls' i.birth_yr i.canton_fe if female==1, cluster(canton_fe)
	estadd ysumm
	estimates store f3c	
	
		
	esttab f1a f1b f1c f2a f2b f2c f3a f3b f3c using "${latex}OLStable.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(sibling_num) ///
	/*mtitles("OLS" "1st" "RF" "IV" "OLS" "1st Stage" "RF"  "IV")*/ ///
	title("OLS Estimates of The Effect of Sibling Number on Prob. of Attending Secondary School") ///
	align(ccccccccc) width(\hsize) /*nonotes*/ addnotes("Note: Standard errors adjusted for clustering at canton level. Each observation is at the child level.")
 	



use creles_iv_notwins2, clear
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	
	keep if parity<=2

	local controls anysis birth2 mom_yrschool mom_age_birth 
	
	qui ivregress 2sls any_sec `controls' female f_anysis i.canton_fe (sibling_num=bb gg), cluster(canton_fe)
	estat firststage
	estat endogenous
	estadd ysumm
	estimates store f1a
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estat firststage
	estat endogenous

	estadd ysumm
	estimates store f1b
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estat firststage
	estat endogenous
	
	estadd ysumm
	estimates store f1c
	
/*
	use child_1984_final_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr84a_resprev2
	save child_1984_final_notwins_2, replace*/
	
	use child_1984_final_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe



	keep if birth_order<=2 & cr84a_age>=14
	
	local controls anysis birth2 mom_yrschool mom_age_birth wealth

		
	qui ivregress 2sls any_sec `controls' female f_anysis i.birth_yr i.canton_fe (sibling_num=bb gg), cluster(canton_fe)
	estat firststage
	estat endogenous
	estadd ysumm
	estimates store f2a
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estat firststage
	estat endogenous
	estadd ysumm
	estimates store f2b
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estat firststage
	estat endogenous
	estadd ysumm
	estimates store f2c	
	
	
	/*
	use child_2000_iv_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr00a_res5cant
	save child_2000_iv_notwins_2, replace*/

	use child_2000_iv_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	keep if birth_order<=2 & cr00a_age>=14

	local controls anysis birth2 mom_yrschool mom_age_birth wealth
	
	qui ivregress 2sls any_sec `controls' female f_anysis i.birth_yr i.canton_fe (sibling_num=bb gg), cluster(canton_fe)
	estadd ysumm
	estat endogenous
	estimates store f3a
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estat endogenous

	estadd ysumm
	
	estimates store f3b
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estat endogenous

	estadd ysumm
	estimates store f3c	
	

	
		
	esttab f1a f1b f1c f2a f2b f2c f3a f3b f3c using "${latex}2slstable.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(sibling_num) ///
	nomtitles/*mtitles("OLS" "1st" "RF" "IV" "OLS" "1st Stage" "RF"  "IV")*/ ///
	title("2sls Estimates of The Effect of Sibling Number on Prob. of Attending Secondary School") ///
	align(ccccccccc) width(\hsize) /*nonotes*/ addnotes("Note: Standard errors adjusted for clustering at canton level. Each observation is at the child level.")
 	


	use creles_iv_notwins, clear

	gen any_sec = attend_second
save creles_iv_notwins2, replace

use creles_iv_notwins2, clear
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	
	keep if parity<=2

	local controls anysis birth2 mom_yrschool mom_age_birth 
	
	qui ivregress 2sls any_sec `controls' female f_anysis i.canton_fe (sibling_num=bb gg), cluster(canton_fe)

	estadd ysumm
	estimates store f1a
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estadd ysumm
	estimates store f1b
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estadd ysumm
	estimates store f1c
	
/*
	use child_1984_final_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr84a_resprev2
	save child_1984_final_notwins_2, replace*/
	
	use child_1984_final_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	
	
	
	keep if birth_order<=2 & cr84a_age>=14
	
	local controls /*anysis*/ birth2 mom_yrschool mom_age_birth wealth

		/*
	ivregress 2sls any_sec `controls' female i.birth_yr i.canton_fe (sibling_num=bb gg), cluster(canton_fe) first
	estadd ysumm
	estimates store f2a
	
	ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estadd ysumm
	estimates store f2b*/
	
	ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estadd ysumm
	estimates store f2c	
	
	
	/*
	use child_2000_iv_notwins, clear
	gen birth2 = (birth_order==2)
	gen f_anysis = female* anysis
	gen canton_fe = cr00a_res5cant
	save child_2000_iv_notwins_2, replace*/

	use child_2000_iv_notwins_2, clear
	
	fvset base 1 birth_yr
	fvset base 1 canton_fe


	keep if birth_order<=2 & cr00a_age>=14

	local controls anysis birth2 mom_yrschool mom_age_birth wealth
	
	qui ivregress 2sls any_sec `controls' female f_anysis i.birth_yr i.canton_fe (sibling_num=bb gg), cluster(canton_fe)
	estat firststage
	estadd ysumm
	estimates store f3a
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==0, cluster(canton_fe)
	estat firststage
	estadd ysumm
	estimates store f3b
	
	qui ivregress 2sls any_sec `controls' i.birth_yr i.canton_fe (sibling_num=bb gg) if female==1, cluster(canton_fe)
	estat firststage
	estadd ysumm
	estimates store f3c	
	

	
		
	esttab f1a f1b f1c f2a f2b f2c f3a f3b f3c using "${latex}2slstable.tex", replace b(%9.4f) ///	
	se scalars("ymean Mean of Dep Var" "N Number of Observations" "r2 R squared") sfmt(%9.2f %12.0gc %9.2f) ///
	star(* 0.1 ** 0.05 *** 0.01 **** 0.001) noobs label keep(sibling_num) ///
	nomtitles/*mtitles("OLS" "1st" "RF" "IV" "OLS" "1st Stage" "RF"  "IV")*/ ///
	title("2sls Estimates of The Effect of Sibling Number on Prob. of Attending Secondary School") ///
	align(ccccccccc) width(\hsize) /*nonotes*/ addnotes("Note: Standard errors adjusted for clustering at canton level. Each observation is at the child level.")
 	
/// Figure 2

use "$CRELES/sample2_combined.dta", replace
	collapse (mean) num_child attend_second mom_birthyr_final, by (CASEID)
	collapse (mean) num_child attend_second, by (mom_birthyr_final)
	la var num_child "Mean number of children"
	la var attend_second "Mean secondary school attendance"
  	
  	twoway connected num_child mom_birthyr_final, yaxis(1) msymbol(O) mfcolor(white) mlcolor(black) msize(m) ///
		|| connected attend_second mom_birthyr_final, yaxis(2) msymbol(T) mcolor(gs10) msize(m) ///
		||, /*title("Number of Children Born and Children's Education by Mother Cohort", size(4))*/ ///
			/*ylabel(0(.1)1)*/ xtitle("Mother's Birth Year") xlabel(1930(5)1960) /*xtitle("Number of Siblings")*/
	graph export fert_edu_trend.png, replace


	
